# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63onnector.proto\x12\x13\x63onnector.connector\x1a\x19google/protobuf/any.proto\"\x84\x01\n\x0fOverviewRequest\x12\x13\n\x0b\x63hart_uuids\x18\x01 \x03(\t\x12\x15\n\roverview_uuid\x18\x02 \x01(\t\x12:\n\x06params\x18\x03 \x01(\x0b\x32%.connector.connector.DispatcherParamsH\x00\x88\x01\x01\x42\t\n\x07_params\"n\n\x11\x44ispatcherRequest\x12\x12\n\nchart_uuid\x18\x01 \x01(\t\x12:\n\x06params\x18\x02 \x01(\x0b\x32%.connector.connector.DispatcherParamsH\x00\x88\x01\x01\x42\t\n\x07_params\"E\n\x10\x44ispatcherFilter\x12\x0e\n\x06metric\x18\x01 \x01(\t\x12\x11\n\topterator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\xb6\x01\n\x10\x44ispatcherParams\x12\x12\n\nstart_date\x18\x01 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x02 \x01(\t\x12\x36\n\x07\x66ilters\x18\x03 \x03(\x0b\x32%.connector.connector.DispatcherFilter\x12\x18\n\x10requested_fields\x18\x04 \x03(\t\x12\x19\n\x0csession_uuid\x18\x05 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_session_uuid\"\\\n\x12\x44ispatcherResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06\x63\x61\x63hed\x18\x02 \x01(\x08\x12%\n\x07payload\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any2\xba\x02\n\x10\x43onnectorService\x12_\n\nDispatcher\x12&.connector.connector.DispatcherRequest\x1a\'.connector.connector.DispatcherResponse0\x01\x12\x64\n\x13OverviewCacheUpdate\x12$.connector.connector.OverviewRequest\x1a\'.connector.connector.DispatcherResponse\x12_\n\x0cOverviewData\x12$.connector.connector.OverviewRequest\x1a\'.connector.connector.DispatcherResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OVERVIEWREQUEST']._serialized_start=68
  _globals['_OVERVIEWREQUEST']._serialized_end=200
  _globals['_DISPATCHERREQUEST']._serialized_start=202
  _globals['_DISPATCHERREQUEST']._serialized_end=312
  _globals['_DISPATCHERFILTER']._serialized_start=314
  _globals['_DISPATCHERFILTER']._serialized_end=383
  _globals['_DISPATCHERPARAMS']._serialized_start=386
  _globals['_DISPATCHERPARAMS']._serialized_end=568
  _globals['_DISPATCHERRESPONSE']._serialized_start=570
  _globals['_DISPATCHERRESPONSE']._serialized_end=662
  _globals['_CONNECTORSERVICE']._serialized_start=665
  _globals['_CONNECTORSERVICE']._serialized_end=979
# @@protoc_insertion_point(module_scope)
