# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: company.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rcompany.proto\x12\x11\x63onnector.company\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"(\n\x11\x43ompanyGetRequest\x12\x13\n\x0b\x63ompany_key\x18\x01 \x01(\t\"\x7f\n\x14\x43ompanyCreateRequest\x12\x15\n\rplatform_uuid\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x30\n\rconfiguration\x18\x08 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x88\x01\x01\x42\x10\n\x0e_configuration\"\x9b\x01\n\x14\x43ompanyUpdateRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x15\n\rplatform_uuid\x18\x02 \x03(\t\x12\x11\n\x04name\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x30\n\rconfiguration\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x10\n\x0e_configuration\"\x97\x04\n\x0f\x43ompanyResponse\x12\x38\n\toperation\x18\x01 \x01(\x0e\x32 .connector.company.OperationEnumH\x00\x88\x01\x01\x12\x14\n\x07success\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x11\n\x04uuid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12G\n\tplatforms\x18\x04 \x01(\x0b\x32/.connector.company.CompanyResponse.platform_idsH\x03\x88\x01\x01\x12\x10\n\x03key\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x11\n\x04name\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x30\n\rconfiguration\x18\x07 \x01(\x0b\x32\x14.google.protobuf.AnyH\x06\x88\x01\x01\x12\x33\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x07\x88\x01\x01\x12\x33\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x1a%\n\x0cplatform_ids\x12\x15\n\rplatform_uuid\x18\x01 \x03(\tB\x0c\n\n_operationB\n\n\x08_successB\x07\n\x05_uuidB\x0c\n\n_platformsB\x06\n\x04_keyB\x07\n\x05_nameB\x10\n\x0e_configurationB\r\n\x0b_created_atB\r\n\x0b_updated_at*F\n\rOperationEnum\x12\x07\n\x03GET\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x08\n\x04READ\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x32\x8f\x02\n\x0e\x43ompanyService\x12O\n\x03Get\x12$.connector.company.CompanyGetRequest\x1a\".connector.company.CompanyResponse\x12U\n\x06\x43reate\x12\'.connector.company.CompanyCreateRequest\x1a\".connector.company.CompanyResponse\x12U\n\x06Update\x12\'.connector.company.CompanyUpdateRequest\x1a\".connector.company.CompanyResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'company_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OPERATIONENUM']._serialized_start=963
  _globals['_OPERATIONENUM']._serialized_end=1033
  _globals['_COMPANYGETREQUEST']._serialized_start=96
  _globals['_COMPANYGETREQUEST']._serialized_end=136
  _globals['_COMPANYCREATEREQUEST']._serialized_start=138
  _globals['_COMPANYCREATEREQUEST']._serialized_end=265
  _globals['_COMPANYUPDATEREQUEST']._serialized_start=268
  _globals['_COMPANYUPDATEREQUEST']._serialized_end=423
  _globals['_COMPANYRESPONSE']._serialized_start=426
  _globals['_COMPANYRESPONSE']._serialized_end=961
  _globals['_COMPANYRESPONSE_PLATFORM_IDS']._serialized_start=810
  _globals['_COMPANYRESPONSE_PLATFORM_IDS']._serialized_end=847
  _globals['_COMPANYSERVICE']._serialized_start=1036
  _globals['_COMPANYSERVICE']._serialized_end=1307
# @@protoc_insertion_point(module_scope)
