# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import connect_portal_pb2 as connect__portal__pb2


class ConnectPortalServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/connector.connect_portal.ConnectPortalService/Get',
                request_serializer=connect__portal__pb2.PortalGetRequest.SerializeToString,
                response_deserializer=connect__portal__pb2.PortalResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/connector.connect_portal.ConnectPortalService/Create',
                request_serializer=connect__portal__pb2.PortalCreateRequest.SerializeToString,
                response_deserializer=connect__portal__pb2.PortalResponse.FromString,
                )
        self.Read = channel.unary_unary(
                '/connector.connect_portal.ConnectPortalService/Read',
                request_serializer=connect__portal__pb2.PortalReadRequest.SerializeToString,
                response_deserializer=connect__portal__pb2.PortalsResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/connector.connect_portal.ConnectPortalService/Update',
                request_serializer=connect__portal__pb2.PortalUpdateRequest.SerializeToString,
                response_deserializer=connect__portal__pb2.PortalResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/connector.connect_portal.ConnectPortalService/Delete',
                request_serializer=connect__portal__pb2.PortalDeleteRequest.SerializeToString,
                response_deserializer=connect__portal__pb2.PortalResponse.FromString,
                )
        self.CheckAuthentication = channel.unary_unary(
                '/connector.connect_portal.ConnectPortalService/CheckAuthentication',
                request_serializer=connect__portal__pb2.PortalMetricRequest.SerializeToString,
                response_deserializer=connect__portal__pb2.PortalResponse.FromString,
                )


class ConnectPortalServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Read(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAuthentication(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConnectPortalServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=connect__portal__pb2.PortalGetRequest.FromString,
                    response_serializer=connect__portal__pb2.PortalResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=connect__portal__pb2.PortalCreateRequest.FromString,
                    response_serializer=connect__portal__pb2.PortalResponse.SerializeToString,
            ),
            'Read': grpc.unary_unary_rpc_method_handler(
                    servicer.Read,
                    request_deserializer=connect__portal__pb2.PortalReadRequest.FromString,
                    response_serializer=connect__portal__pb2.PortalsResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=connect__portal__pb2.PortalUpdateRequest.FromString,
                    response_serializer=connect__portal__pb2.PortalResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=connect__portal__pb2.PortalDeleteRequest.FromString,
                    response_serializer=connect__portal__pb2.PortalResponse.SerializeToString,
            ),
            'CheckAuthentication': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAuthentication,
                    request_deserializer=connect__portal__pb2.PortalMetricRequest.FromString,
                    response_serializer=connect__portal__pb2.PortalResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'connector.connect_portal.ConnectPortalService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConnectPortalService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.connect_portal.ConnectPortalService/Get',
            connect__portal__pb2.PortalGetRequest.SerializeToString,
            connect__portal__pb2.PortalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.connect_portal.ConnectPortalService/Create',
            connect__portal__pb2.PortalCreateRequest.SerializeToString,
            connect__portal__pb2.PortalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Read(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.connect_portal.ConnectPortalService/Read',
            connect__portal__pb2.PortalReadRequest.SerializeToString,
            connect__portal__pb2.PortalsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.connect_portal.ConnectPortalService/Update',
            connect__portal__pb2.PortalUpdateRequest.SerializeToString,
            connect__portal__pb2.PortalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.connect_portal.ConnectPortalService/Delete',
            connect__portal__pb2.PortalDeleteRequest.SerializeToString,
            connect__portal__pb2.PortalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAuthentication(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/connector.connect_portal.ConnectPortalService/CheckAuthentication',
            connect__portal__pb2.PortalMetricRequest.SerializeToString,
            connect__portal__pb2.PortalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
