# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: connect_portal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x63onnect_portal.proto\x12\x18\x63onnector.connect_portal\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\'\n\x10PortalGetRequest\x12\x13\n\x0bportal_uuid\x18\x01 \x01(\t\")\n\x11PortalReadRequest\x12\x14\n\x0c\x63ompany_uuid\x18\x01 \x01(\t\"*\n\x13PortalDeleteRequest\x12\x13\n\x0bportal_uuid\x18\x01 \x01(\t\"*\n\x13PortalMetricRequest\x12\x13\n\x0bportal_uuid\x18\x01 \x01(\t\"\xab\x01\n\x13PortalCreateRequest\x12\x14\n\x0c\x63ompany_uuid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x30\n\x04type\x18\x03 \x01(\x0e\x32\".connector.connect_portal.TypeEnum\x12\x11\n\tclassName\x18\x04 \x01(\t\x12+\n\rconfiguration\x18\x05 \x01(\x0b\x32\x14.google.protobuf.Any\"\x8a\x01\n\x13PortalUpdateRequest\x12\x13\n\x0bportal_uuid\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x30\n\rconfiguration\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x10\n\x0e_configuration\"\x85\x04\n\x0ePortalResponse\x12?\n\toperation\x18\x01 \x01(\x0e\x32\'.connector.connect_portal.OperationEnumH\x00\x88\x01\x01\x12\x14\n\x07success\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x11\n\x04uuid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x35\n\x04type\x18\x05 \x01(\x0e\x32\".connector.connect_portal.TypeEnumH\x04\x88\x01\x01\x12\x10\n\x03key\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tclassName\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x30\n\rconfiguration\x18\x08 \x01(\x0b\x32\x14.google.protobuf.AnyH\x07\x88\x01\x01\x12\x33\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x08\x88\x01\x01\x12\x33\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\t\x88\x01\x01\x42\x0c\n\n_operationB\n\n\x08_successB\x07\n\x05_uuidB\x07\n\x05_nameB\x07\n\x05_typeB\x06\n\x04_keyB\x0c\n\n_classNameB\x10\n\x0e_configurationB\r\n\x0b_created_atB\r\n\x0b_updated_at\"\x99\x01\n\x0fPortalsResponse\x12:\n\toperation\x18\x01 \x01(\x0e\x32\'.connector.connect_portal.OperationEnum\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x39\n\x07portals\x18\x03 \x03(\x0b\x32(.connector.connect_portal.PortalResponse*1\n\x08TypeEnum\x12\x07\n\x03\x41TS\x10\x00\x12\x0b\n\x07\x43HANNEL\x10\x01\x12\x0f\n\x0bINTEGRATION\x10\x02*b\n\rOperationEnum\x12\x07\n\x03GET\x10\x00\x12\n\n\x06\x43REATE\x10\x01\x12\x08\n\x04READ\x10\x02\x12\n\n\x06UPDATE\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x12\x08\n\x04SYNC\x10\x05\x12\x10\n\x0c\x41UTHENTICATE\x10\x06\x32\xec\x04\n\x14\x43onnectPortalService\x12[\n\x03Get\x12*.connector.connect_portal.PortalGetRequest\x1a(.connector.connect_portal.PortalResponse\x12\x61\n\x06\x43reate\x12-.connector.connect_portal.PortalCreateRequest\x1a(.connector.connect_portal.PortalResponse\x12^\n\x04Read\x12+.connector.connect_portal.PortalReadRequest\x1a).connector.connect_portal.PortalsResponse\x12\x61\n\x06Update\x12-.connector.connect_portal.PortalUpdateRequest\x1a(.connector.connect_portal.PortalResponse\x12\x61\n\x06\x44\x65lete\x12-.connector.connect_portal.PortalDeleteRequest\x1a(.connector.connect_portal.PortalResponse\x12n\n\x13\x43heckAuthentication\x12-.connector.connect_portal.PortalMetricRequest\x1a(.connector.connect_portal.PortalResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connect_portal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TYPEENUM']._serialized_start=1273
  _globals['_TYPEENUM']._serialized_end=1322
  _globals['_OPERATIONENUM']._serialized_start=1324
  _globals['_OPERATIONENUM']._serialized_end=1422
  _globals['_PORTALGETREQUEST']._serialized_start=110
  _globals['_PORTALGETREQUEST']._serialized_end=149
  _globals['_PORTALREADREQUEST']._serialized_start=151
  _globals['_PORTALREADREQUEST']._serialized_end=192
  _globals['_PORTALDELETEREQUEST']._serialized_start=194
  _globals['_PORTALDELETEREQUEST']._serialized_end=236
  _globals['_PORTALMETRICREQUEST']._serialized_start=238
  _globals['_PORTALMETRICREQUEST']._serialized_end=280
  _globals['_PORTALCREATEREQUEST']._serialized_start=283
  _globals['_PORTALCREATEREQUEST']._serialized_end=454
  _globals['_PORTALUPDATEREQUEST']._serialized_start=457
  _globals['_PORTALUPDATEREQUEST']._serialized_end=595
  _globals['_PORTALRESPONSE']._serialized_start=598
  _globals['_PORTALRESPONSE']._serialized_end=1115
  _globals['_PORTALSRESPONSE']._serialized_start=1118
  _globals['_PORTALSRESPONSE']._serialized_end=1271
  _globals['_CONNECTPORTALSERVICE']._serialized_start=1425
  _globals['_CONNECTPORTALSERVICE']._serialized_end=2045
# @@protoc_insertion_point(module_scope)
